"""
This scripts shows how to do a simple equilibrium calculation with
EquilibriumCalculation
"""

from chemapp.friendly import (
    ThermochemicalSystem as cats,
    EquilibriumCalculation as caec,
    Info as cai,
    Units)

# load a thermochemical system from a data file
cats.load('../../data/fec.dat')
Units.set()

# Check if we are working with the 'light' version.
# If we do, omit the following phase target calculation(s).
if cai.is_light():
    raise ValueError(f'Target calculations are not supported when using ChemApp Light.'
                     ' This example is included in the documentation to illustrate the'
                     ' abilities available with the full version of ChemApp.')


# convert the thermochemical system to a core.ThermochemicalSystem object
ts = cats.get_object()

# set input parameters
T_feed = 25.00  # C, feed temperature
T_equilib = 1600.00 # C, equilibrium temperature
P_feed = 1.0  # atm, feed pressure
P_equilib = 1.0  # atm, equilibrium pressure
m_fec = 500.0  # kg, mass of cementite added
m_c = 1.0  # kg, mass of graphite added

# set input parameters in ChemApp for Python with EquilibriumCalculation
caec.set_IA_pc('Fe3C_CEMENTITE', 'Fe3C_CEMENTITE', m_fec)
caec.set_IA_pc('C_GRAPHITE', 'C_GRAPHITE', m_c)

# set equilibrium conditions
caec.set_target_formation_of_ph('LIQUID')
caec.set_eq_P(P_equilib)

# calculate equilibrium
caec.calculate_eq_T(T_equilib)

# get amount of liquid alloy formed
T_formation = caec.get_eq_T()

# print result
print(T_formation)