from chemapp.friendly import (
    ThermochemicalSystem as cats,
    PhaseMapCalculation as pmc,
    Units)
from chemapp.core import (
    AmountUnit,
    TemperatureUnit)
import chemapp

from pathlib import Path

# Local ChemApp for Python data directory
cap_path = Path(chemapp.__file__).parent
data_path = cap_path / "data"

# Load the PbSn thermochemical system
cats.load(data_path / 'pbsn.dat')

# Set amount units to kg and temperature units to K
Units.set_A_unit(AmountUnit.kg)
Units.set_T_unit(TemperatureUnit.K)

# Get and print the thermochemical system
ts = cats.get_object()
print(ts)

# Set incoming amounts to 0.8 mol Pb and 0.2 mol Sn
pmc.set_IA_sc("Pb", 0.8)
pmc.set_IA_sc("Sn", 0.2)

# Calculate the one dimensional phase boundaries when varying temperature
results = pmc.calculate_ph_txs_T(300, 700, False)

# Print the results in table format
template = "{TEMP:<30}{PHASES:<30}{AMOUNT:<30}"
print(template.format(
    TEMP="Temperature(K)",
    PHASES="Stable phases",
    AMOUNT="Amount(kg)"))

for result in results:
    print(template.format(TEMP=result.T,
                          PHASES="",
                          AMOUNT=""))
    stable_phases = result.get_eq_phs()
    for stable_phase in stable_phases:
        print(template.format(TEMP="",
                              PHASES=stable_phase.name,
                              AMOUNT=stable_phase.A))