"""
This script gives an example of how to do a phase map calculation with ChemApp for Python
"""

from chemapp.friendly import \
    ThermochemicalSystem as cats, \
    PhaseMapCalculation as pmc

# load a thermochemical system from a data file
cats.load('../../data/femgsio4.dat')

# set parameters
P_equilib = 1  # atm

# set the equilibrium pressure
pmc.set_eq_P(P_equilib)

# create ranges of incoming amounts
fe2sio4_range = pmc.IA_range('Fe2SiO4', '', 0.0, 0.2)
mg2sio4_range = pmc.IA_range('Mg2SiO4', '', 1.0, 0.8)
ranges = [fe2sio4_range, mg2sio4_range]

# calculate phase map results
results = pmc.calculate_ph_txs_IA(ranges, print_results=False)

# Print the results in table format
print('X(Fe2SiO4)     X(Mg2SiO4)       Stable Phases        Amount (mol)')
for result in results:
    print('%f             %f' % (result.IAs[0].A, result.IAs[1].A))
    stable_phases = result.get_eq_phs()
    for stable_phase in stable_phases:
        print('                                %s               %f' % (
            stable_phase.name, stable_phase.A))