"""
This script is a basic example of how an stream equilibrium calculation is done.
"""

from chemapp.friendly import \
    ThermochemicalSystem as cats, \
    StreamCalculation

# load a thermochemical system from a data file
cats.load('../../data/fec.dat')

# get thermochemical system as object
ts = cats.get_object()

# set parameters
T_amb = 25.00 # C
P_amb = 1 # atm
T_equilib = 1500.00 # C
P_equilib = 1 # atm
m_red = 1.0 # kg
m_ore = 500.0 # kg

y_feo = 0.4 # kg/kg, mass fraction feo in ore
y_fe2o3 = 0.6 # kg/kg, mass fraction fe2o3 in ore

m_feo = m_ore*y_feo
m_fe2o3 = m_ore*y_fe2o3

# create ore stream
StreamCalculation.create_st('ore', T_amb, P_amb)
StreamCalculation.set_IA_pc('ore', 'Fe3C_CEMENTITE', 'Fe3C_CEMENTITE',
                            m_feo)


# create reductant stream
StreamCalculation.create_st('reductant', T_amb, P_amb)
StreamCalculation.set_IA_pc('reductant', 'C_GRAPHITE', 'C_GRAPHITE',
                            m_red)

# set equilibrium conditions
StreamCalculation.set_eq_T(T_equilib)
StreamCalculation.set_eq_P(P_equilib)

# calculate equilibrium
StreamCalculation.calculate_eq(print_results=False)

# calculate change in enthalpy
dH = StreamCalculation.get_eq_H()

# print result
print(f'dH reaction: {dH} kWh')