"""
This script is a basic example of how an stream equilibrium calculation is
done with a target precipitation phase.
"""

from chemapp.friendly import \
    ThermochemicalSystem as cats, \
    StreamCalculation

# load a thermochemical system from a data file
cats.load('../../data/fec.dat')

# get thermochemical system as object
ts = cats.get_object()

# set parameters
T_amb = 1600.00  # C
P_amb = 1.0  # atm
T_equilib = 500.00  # C
P_equilib = 1  # atm
m_alloy = 500.0  # kg

y_fe = 0.8  # kg/kg, mass fraction fe in alloy
y_c = 0.05  # kg/kg, mass fraction carbon in alloy

m_fe = m_alloy*y_fe
m_c = m_alloy*y_c

# create alloy stream
StreamCalculation.create_st('alloy', T_amb, P_amb)
StreamCalculation.set_IA_pc('alloy', 'LIQUID', 'Fe',
                            m_fe)
StreamCalculation.set_IA_pc('alloy', 'LIQUID', 'C',
                            m_c)

# set equilibrium conditions
# set precipitation target phase as the liquid alloy
StreamCalculation.set_target_formation_of_ph('LIQUID')
StreamCalculation.set_eq_P(P_equilib)

# calculate equilibrium
StreamCalculation.calculate_eq_T(T_equilib)

# get the temperature at which precipitation occurs
T_precept = StreamCalculation.get_eq_T()

# print result
print(T_precept)