"""
ThermochemicalSystem Example 2
==============================

This example demonstrates how to store a thermochemical system object in a
MongoDB database.
"""

from pymongo import MongoClient

from chemapp.core import DataFormat
from chemapp.friendly import ThermochemicalSystem as cats


def connect_mongo():
    """
    This function connects to the server, database, and collection. It returns
    references to these objects.
    """
    # connect to the server
    server_name = 'localhost'  # use 'localhost' if mongodb is installed locally
    port_number = '27017'
    client = MongoClient(f'mongodb://{server_name}:{port_number}/')


    # connect to a database
    # (the database will be created automatically if it does not exist)
    db_name = 'ChemAppPy_Examples'
    db = client[db_name]


    # connect to a collection
    # (the collection will be created automatically if it does not exist)
    coll_name = 'ThermochemicalSystem_Example2'
    coll = db[coll_name]

    return client, db, coll


def create_thermochemical_system():
    cats.load('../../data/cosi.dat')
    return cats.get_object()


# main program

# connect to the mongodb database
client, db, coll = connect_mongo()

# get the thermochemical system object
ts = create_thermochemical_system()

# store the system in the database
coll.replace_one(
    {'data_file.md5': ts.file_md5},
    ts.convert_to(DataFormat.mongoDbIndexedPrimitiveDoc),
    upsert=True)